"Headless Mode" for In-App Scripting and Development – ShinyBroker

# "Headless Mode" for In-App Scripting and Development

## “Somewhat Interactive” Development Mode, coming soon

As you’re developing apps, it’s sometimes useful to just create a scratch file containing a bit of code that grabs some input. You can watch the information get printed by the async reader loop as it becomes available off the socket, and maybe copy-paste it from the terminal printout do perform some of your exploratory development work.

#### Simple exploratory example:

    # {{< include examples/headless_mode_1.py >}}